@@ -3,7 +3,7 @@ package fa_menu;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright (C) 2000-2014  Brian M. Kelly
+#    Copyright (C) 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -48,8 +48,8 @@ our %Menu_1=(
    },
    Item_3 => {
 
-      Text   => "Image Magick",
-      Result => "&image_magick()",
+      Text   => "Explore Figlet Fonts",
+      Result => "&figlet_fonts()",
 
    },
    Item_4 => {
@@ -60,7 +60,7 @@ our %Menu_1=(
    },
 
    Select => 'One',
-   Banner => "\n   Choose a Task to Perform :"
+   Banner => "\n   Choose a Task to Perform :\n\n"
 );
 
 our $start_menu_ref=\%Menu_1;
