@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::OpenLDAP_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2015  Brian M. Kelly
+#    Copyright © 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -24,6 +24,7 @@ package Net::FullAuto::ISets::Amazon::OpenLDAP_is;
 
 our $VERSION='0.01';
 our $DISPLAY='OpenLDAP™';
+our $CONNECT='ssh';
 our $defaultInstanceType='t2.micro';
 
 use 5.005;
@@ -72,7 +73,8 @@ my $configure_openldap=sub {
    $ver=~s/_.*$//;
    $ver=~s/^.*db-(\d+[.]\d+).*$/$1/;
    my $pre="/usr/local/BerkeleyDB.$ver";
-   ($stdout,$stderr)=$handle->cmd("wget $source",'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+       "wget --random-wait --progress=dot $source",'__display__');
    ($stdout,$stderr)=$handle->cmd("wget ${source}.md5",'__display__');
    ($stdout,$stderr)=$handle->cmd("cat ${tarfile}.md5");
    my $checksum=$stdout;
@@ -98,7 +100,8 @@ my $configure_openldap=sub {
       "http://www.openldap.org/software/download/");
    $url=$stdout;
    $url=~s/^.*?[>]OpenLDAP[<].*?HREF="(.*?tgz)".*$/$1/s;
-   ($stdout,$stderr)=$handle->cmd("sudo wget ".$url,'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "sudo wget --random-wait --progress=dot ".$url,'__display__');
    my $md5=$url;
    $md5=~s/tgz$/md5/;
    $tarfile=$url;
@@ -205,15 +208,21 @@ END
    ($hash,$output,$error)=Net::FullAuto::FA_Core::run_aws_cmd($c);
    my $mdns=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicDnsName};
    my $pbip=$hash->{Reservations}->[0]->{Instances}->[0]->{PublicIpAddress};
-   ($stdout,$stderr)=$handle->cmd("wget -qO- ".
-      "http://sourceforge.net/projects/phpldapadmin/files");
-   $stdout=~s/^.*latest\/download.*?title="(.*?):.*$/$1/s;
-   ($stdout,$stderr)=$handle->cmd('sudo '.
-      "wget http://sourceforge.net/projects/phpldapadmin/files$stdout",
-      '__display__');
+   my $dcnt=0;
+   while (1) {
+      ($stdout,$stderr)=$handle->cmd("wget --random-wait -qO- ".
+         "http://sourceforge.net/projects/phpldapadmin/files");
+      $stdout=~s/^.*latest\/download.*?title="(.*?):.*$/$1/s;
+      ($stdout,$stderr)=$handle->cmd('sudo '.
+         "wget --random-wait --progress=dot ".
+         "http://sourceforge.net/projects/phpldapadmin/files$stdout",
+         '__display__');
+      next if (-1<index $stderr,'ERROR 404') && $dcnt++<3;
+      last
+   }
    ($stdout,$stderr)=$handle->cmd("sudo tar zxvf *tgz",'__display__');
    ($stdout,$stderr)=$handle->cmd("sudo rm -vf *tgz",'__display__');
-   ($stdout,$stderr)=$handle->cmd("sudo mv phpldapadmin* phpldapadmin",
+   ($stdout,$stderr)=$handle->cmd("sudo mv -T phpldapadmin* phpldapadmin",
       '__display__');
    ($stdout,$stderr)=$handle->cmd(
       "sudo cp -v phpldapadmin/config/con* phpldapadmin/config/config.php",
@@ -235,7 +244,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -297,11 +306,12 @@ my $standup_openldap=sub {
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    my $cnt=0;
-   $pem_file=~s/\.pem\s*$//s;
+   my $pemfile=$pem_file;
+   $pemfile=~s/\.pem\s*$//s;
    if (exists $main::aws->{'OpenLDAP.org'}) {
       my $g=get_aws_security_id('OpenLDAPSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pem_file ".
+         "--instance-type $type --key-name $pemfile ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'OpenLDAP.org'}}==0) {
          launch_server('OpenLDAP.org',$cnt,$openldap,'',$c,
